@@ -6,7 +6,7 @@
 
 
 
-set -e
+set -ex
 
 MYTEMP_DIR=`mktemp -d`
 ME=`whoami`
@@ -40,7 +40,4 @@ cleanup() {
 }
 trap cleanup INT EXIT TERM
 
-# ruby-mysql2 tests use the "test" db.
-mysqladmin --user=${DO_MYSQL_USER} --socket=${MYSQL_UNIX_PORT} create test
-
 "$@"
